package com.sooka.system.service.impl;

import java.util.List;

import com.sooka.common.annotation.DataSource;
import com.sooka.common.core.text.Convert;
import com.sooka.common.enums.DataSourceType;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.sooka.system.mapper.TgjjKjhzbMapper;
import com.sooka.system.domain.TgjjKjhzb;
import com.sooka.system.service.ITgjjKjhzbService;

/**
 * 会计汇总报（年、季、月）Service业务层处理
 *
 * @author lei
 * @date 2021-11-16
 */
@Service

public class TgjjKjhzbServiceImpl extends Guiji_Base_Service implements ITgjjKjhzbService
{
    @Autowired
    private TgjjKjhzbMapper tgjjKjhzbMapper;

    /**
     * 查询会计汇总报（年、季、月）
     *
     * @param ID 会计汇总报（年、季、月）ID
     * @return 会计汇总报（年、季、月）
     */
    @Override
    public TgjjKjhzb selectTgjjKjhzbById(Long ID)
    {
        return tgjjKjhzbMapper.selectTgjjKjhzbById(ID);
    }

    /**
     * 查询会计汇总报（年、季、月）列表
     *
     * @param tgjjKjhzb 会计汇总报（年、季、月）
     * @return 会计汇总报（年、季、月）
     */
    @Override
    public List<TgjjKjhzb> selectTgjjKjhzbList(TgjjKjhzb tgjjKjhzb)
    {
        List ls =  tgjjKjhzbMapper.selectTgjjKjhzbList(tgjjKjhzb);
        tgjjKjhzb.setInterfaceinfoId("43e7fece-cf97-4de6-b760-1239b4cb1d4c");
        tgjjKjhzb.setInterfaceinfoName("共享-市公积金-会计汇总报");
        tgjjKjhzb.setInterfacetype("platform_interfacetype_1");
        add_log(tgjjKjhzb);
        return ls;
    }

    /**
     * 新增会计汇总报（年、季、月）
     *
     * @param tgjjKjhzb 会计汇总报（年、季、月）
     * @return 结果
     */
    @Override
    public int insertTgjjKjhzb(TgjjKjhzb tgjjKjhzb)
    {
        return tgjjKjhzbMapper.insertTgjjKjhzb(tgjjKjhzb);
    }

    /**
     * 修改会计汇总报（年、季、月）
     *
     * @param tgjjKjhzb 会计汇总报（年、季、月）
     * @return 结果
     */
    @Override
    public int updateTgjjKjhzb(TgjjKjhzb tgjjKjhzb)
    {
        return tgjjKjhzbMapper.updateTgjjKjhzb(tgjjKjhzb);
    }

    /**
     * 删除会计汇总报（年、季、月）对象
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTgjjKjhzbByIds(String ids)
    {
        return tgjjKjhzbMapper.deleteTgjjKjhzbByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除会计汇总报（年、季、月）信息
     *
     * @param ID 会计汇总报（年、季、月）ID
     * @return 结果
     */
    @Override
    public int deleteTgjjKjhzbById(Long ID)
    {
        return tgjjKjhzbMapper.deleteTgjjKjhzbById(ID);
    }
}
